pub struct Sector {
pub id: SectorId,
pub name: Option<String>,
pub level: u8,
pub coord: Coordinates,
pub bounds: Vec<Coordinates>,
pub chat_link: String,
}Fields
id: SectorIdThe sector id.
name: Option<String>The name of the sector, if any.
level: u8The level of the sector.
coord: CoordinatesThe coordinates of the sector (this is usually the center position).
bounds: Vec<Coordinates>A list of coordinates marking the boundary of the sector.
chat_link: StringThe sector chat link (provides an invalid link if attempting to display in-game).