SkillChallenge

Struct SkillChallenge 

pub struct SkillChallenge {
    pub id: Option<String>,
    pub coord: Coordinates,
}

Fields

id: Option<String>

The hero challenge id, if any.

It is formed of two numbers separated by a dash. The first number represents the expansion (0 for Core Tyria, 1 for Heart of Thorns and 2 for Path of Fire), and therefore could be used to change the hero challenge map marker icon. If the first number and dash prefix is removed from the string, the second number is no longer unique among other hero challenges.

coord: Coordinates

The coordinates of this hero challenge.